"""
This file is part of the SiEPIC_EBeam_PDK
by Dream Photonics, 2023

This file implements a library called "EBeam-Dream",
consisting of components developed by Dream Photonics Inc,
that have been validated in the ANT process.
"""

